@@ -230,7 +230,8 @@ def determine_if_sne_are_discoverable(
         discoverableList.append(discoveryDict)
 
 
-    maxVal = np.max(redshiftArray)
+    maxVal = np.max(redshiftArray)*1.1
+
 
     if plot:
         hitList = []
